var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { KaCustomModal } from "@kasimirjs/embed";
const html = `
<div class="modal d-block" tabindex="-1">
    <div class="modal-dialog modal-xl">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">%%title%%</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" ka.on.click="$fn.close()" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                %%body%%
            </div>
            <div class="modal-footer">
               
                %%buttons%%
            </div>
        </div>
    </div>
</div>`;
export class FlexModalConfig {
    constructor() {
        this.title = "unnamed";
        this.size = "xl";
    }
}
export class FlexModal extends KaCustomModal {
    /**
     *
     * Example:
     * const m = new FlexModal("My Title", "<div>[[message]]</div>", [`<button ka.on.click="$fn.resolve()">Save</button>`]);
     * let result = await m.show({message: "Hello World"});
     * console.log(result.message);
     *
     * @param title
     * @param body
     * @param buttons
     * @param initScope
     */
    constructor(title, body, buttons = null, initScope = {}) {
        super();
        this.initScope = initScope;
        if (buttons === null)
            buttons = [`<button type="button" class="btn btn-secondary" ka.on.click="$fn.close()">Close</button>`]; // Add close button if no buttons are present.
        this.__html = html.replace("%%title%%", title).replace("%%body%%", body).replace("%%buttons%%", buttons.join(" "));
    }
    /**
     *
     *
     * @param scope     Optional Scope to pass to the modal
     * @param parser    Optional Callback to parse the return value before resolving the promise
     */
    show(scope = {}, parser = (scope) => { return scope; }) {
        const _super = Object.create(null, {
            show: { get: () => super.show }
        });
        return __awaiter(this, void 0, void 0, function* () {
            let defaultScope = this.initScope;
            let instance = this;
            let myScope = this.init(Object.assign(Object.assign({}, defaultScope), scope));
            if (!myScope.$fn)
                myScope.$fn = {};
            myScope.$fn['close'] = () => {
                this.resolve(null);
            };
            myScope.$fn['resolve'] = () => {
                this.resolve(parser(myScope));
            };
            return _super.show.call(this);
        });
    }
}
